@@ -1026,6 +1026,12 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
 class UploadSequencePlayblastsToKitsu(ProcessSequenceFiles):
     
     ICON = ('icons.libreflow', 'kitsu-upload')
+
+    def allow_context(self, context):
+        return (
+            context
+            and self.root().project().kitsu_config().configured.get()
+        )
     
     def get_task_statutes(self):
         return self.root().project().kitsu_api().get_task_statutes()
