@@ -31,7 +31,6 @@ class Shot(baseflow.film.Shot):
 class Shots(baseflow.film.Shots):
 
     create_shot = flow.Child(baseflow.maputils.SimpleCreateAction)
-    clear_shots = flow.Child(baseflow.maputils.ClearMapAction).ui(hidden=True)
     with flow.group("Kitsu"):
         toggle_kitsu_settings = flow.Child(baseflow.film.DisplayKitsuSettings)
         update_kitsu_settings = flow.Child(baseflow.film.UpdateItemsKitsuSettings)
@@ -141,7 +140,6 @@ class Episodes(flow.Map):
     ICON = ("icons.flow", "film")
 
     create_episode = flow.Child(baseflow.maputils.SimpleCreateAction)
-    clear_episodes = flow.Child(baseflow.maputils.ClearMapAction)
 
     @classmethod
     def mapped_type(cls):
